import { Calendar, Switch } from 'antd';
import { FC } from 'react';

import { useTheme, useThemeActions } from './hooks';
import $styles from './style.module.css';

const Setting: FC = () => {
    const { mode, compact } = useTheme();
    const { toggleMode, toggleCompact } = useThemeActions();
    return (
        <>
            <Switch
                checkedChildren="🌛"
                unCheckedChildren="☀️"
                onChange={toggleMode}
                checked={mode === 'dark'}
                defaultChecked={mode === 'dark'}
            />
            <Switch
                checkedChildren="紧凑"
                unCheckedChildren="正常"
                onChange={toggleCompact}
                checked={compact}
                defaultChecked={compact}
            />
        </>
    );
};

const ThemeDemo: FC = () => {
    const { mode, compact } = useTheme();
    return (
        <div className={$styles.container}>
            <h2 className="tw-text-center">Theme Setting Demo</h2>
            <div className="tw-flex tw-items-center tw-flex-col">
                <p>主题模式: 「{mode === 'dark' ? '暗黑' : '明亮'}」</p>
                <p>是否紧凑: 「{compact ? '是' : '否'}」</p>
                <div className="tw-flex-auto tw-mb-5">
                    <Setting />
                </div>
                <div className="tw-max-w-md">
                    <Calendar fullscreen={false} />
                </div>
            </div>
        </div>
    );
};
export default ThemeDemo;
